@@ -336,7 +336,7 @@ class MainWindow(QtGui.QMainWindow):
                                   "General score: "+str(sc_general)+"\n"
                                   "Award score: "+str(sc_award)+"\n"
                                   "Objective score: "+str(sc_objective)+"\n"
-                                  "Demolition score: "+str(sc_demo)+"\n"
+                                  "Engineer score: "+str(sc_demo)+"\n"
                                   "Recon score: "+str(sc_recon)+"\n"
                                   "Assault score: "+str(sc_assault)+"\n"
                                   "Support score: "+str(sc_support)+"\n"
